package com.ruoyi.project.ticket.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.ticket.mapper.TFireWorkPermitMapper;
import com.ruoyi.project.ticket.domain.TFireWorkPermit;
import com.ruoyi.project.ticket.service.ITFireWorkPermitService;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2022-02-23
 */
@Service
public class TFireWorkPermitServiceImpl implements ITFireWorkPermitService
{
    @Autowired
    private TFireWorkPermitMapper tFireWorkPermitMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param hId 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public TFireWorkPermit selectTFireWorkPermitById(Long hId)
    {
        return tFireWorkPermitMapper.selectTFireWorkPermitById(hId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tFireWorkPermit 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TFireWorkPermit> selectTFireWorkPermitList(TFireWorkPermit tFireWorkPermit)
    {
        return tFireWorkPermitMapper.selectTFireWorkPermitList(tFireWorkPermit);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param tFireWorkPermit 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTFireWorkPermit(TFireWorkPermit tFireWorkPermit)
    {
        return tFireWorkPermitMapper.insertTFireWorkPermit(tFireWorkPermit);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param tFireWorkPermit 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTFireWorkPermit(TFireWorkPermit tFireWorkPermit)
    {
        return tFireWorkPermitMapper.updateTFireWorkPermit(tFireWorkPermit);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param hIds 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteTFireWorkPermitByIds(Long[] hIds)
    {
        return tFireWorkPermitMapper.deleteTFireWorkPermitByIds(hIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param hId 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteTFireWorkPermitById(Long hId)
    {
        return tFireWorkPermitMapper.deleteTFireWorkPermitById(hId);
    }
}
